Kuna exchange API wrapper
=========================


.. image:: https://img.shields.io/pypi/v/kuna.svg
        :target: https://pypi.python.org/pypi/kuna

.. image:: https://travis-ci.org/DmytroLitvinov/kuna.svg?branch=master
        :target: https://travis-ci.org/DmytroLitvinov/kuna

.. image:: https://coveralls.io/repos/github/DmytroLitvinov/kuna/badge.svg?branch=master
        :target: https://coveralls.io/github/DmytroLitvinov/kuna?branch=master

.. image:: https://readthedocs.org/projects/kuna/badge/?version=stable
        :target: https://kuna.readthedocs.io/en/latest/?badge=stable
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/DmytroLitvinov/kuna/shield.svg
     :target: https://pyup.io/repos/github/DmytroLitvinov/kuna/
     :alt: Updates

.. image:: https://pyup.io/repos/github/DmytroLitvinov/kuna/python-3-shield.svg
     :target: https://pyup.io/repos/github/DmytroLitvinov/kuna/
     :alt: Python 3

``kuna`` is a Python package providing access to the `Kuna exchange <https://kuna.io/>`_ server API.
Original documentation of Kuna exchange API here: https://kuna.io/documents/api


Installation
============

Requirements
------------

kuna depends on:

* `python-requests <http://docs.python-requests.org/en/latest/>`_

Install with pip
----------------

.. code-block:: console

   pip install kuna


Usage example
=============

* TODO

Documentation
=============

The full documentation forAPI is available on `readthedocs <https://kuna.readthedocs.io>`_.

Meta
====

Dmytro Litvinov – `@Dmytro_Litvinov <https://twitter.com/Dmytro_Litvinov>`_  – litvinov.do.it@gmail.com

Distributed under the MIT license. See `LICENSE <https://github.com/DmytroLitvinov/kuna/blob/master/LICENSE>`_ for more information.

https://github.com/DmytroLitvinov/kuna

